from sports.nba.nba_team import NBA_Team


class WashingtonWizards(NBA_Team):
    """
    NBA's Washington Wizards Static Information

    """
    full_name = "Washington Wizards"
    name = "Wizards"
    team_id = 1610612764

    def __init__(self):
        """
        """
        super().__init__()



from sports.nba.nba_team import NBA_Team


class ClevelandCavaliers(NBA_Team):
    """
    NBA Atlanta Hawks Static Information

    """
    full_name = "Cleveland Cavaliers"
    name = "Cavaliers"
    team_id = 1610612739

    def __init__(self):
        """
        """
        super().__init__()


from sports.nba.nba_team import NBA_Team


class MinnesotaTimberwolves(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """

    full_name = "Minnesota Timberwolves"
    name = "Timberwolves"
    team_id = 1610612750

    def __init__(self):
        """
        """
        super().__init__()




from .atlanta_hawks             import AtlantaHawks
from .boston_celtics            import BostonCeltics
from .brooklyn_nets             import BrooklynNets
from .chicago_bulls             import ChicagoBulls
from .cleveland_cavaliers       import ClevelandCavaliers
from .denver_nuggets            import DenverNuggets
from .detroit_pistons           import DetroitPistons
from .golden_state_warriors    import GoldenStateWarriors
from .houston_rockets           import HoustonRockets
from .indiana_pacers            import IndianaPacers
from .los_angeles_clippers      import LosAngelesClippers
from .los_angeles_lakers        import LosAngelesLakers
from .memphis_grizzlies         import MemphisGrizzlies
from .miami_heat                import MiamiHeat
from .milwaukee_bucks           import MilwaukeeBucks
from .minnesota_timberwolves    import MinnesotaTimberwolves
from .new_orleans_pelicans      import NewOrleansPelicans
from .new_york_knickerbockers   import NewYorkKnickerbockers
from .oklahoma_thunder          import OklahomaThunder
from .orlando_magic             import OrlandoMagic
from .philadelphia_76ers        import Philadelphia76ers
from .phoenix_suns              import PhoenixSuns
from .portland_trail_blazers    import PortlandTrailBlazers
from .sacramento_kings          import SacramentoKings
from .san_antonio_spurs         import SanAntonioSpurs
from .toronto_raptors           import TorontoRaptors
from .utah_jazz                 import UtahJazz
from .washington_wizards        import WashingtonWizards

__all__ = ['AtlantaHawks','BostonCeltics','BrooklynNets','ChicagoBulls','ClevelandCavaliers','DenverNuggets',
           'DetroitPistons','GoldenStateWarriors','HoustonRockets','IndianaPacers','LosAngelesClippers',
           'LosAngelesLakers','MemphisGrizzlies','MiamiHeat','MilwaukeeBucks','MinnesotaTimberwolves',
           'NewOrleansPelicans','NewYorkKnickerbockers','OklahomaThunder','OrlandoMagic','Philadelphia76ers',
           'PhoenixSuns','PortlandTrailBlazers','SacramentoKings','SanAntonioSpurs','TorontoRaptors',
           'UtahJazz','WashingtonWizards']



import xml.sax
from sports.models.Scoreboard import Scoreboard
from sports.models.Game import Game

class ScoreboardXml(xml.sax.ContentHandler):
    """
    Parse the scoreboard.xml
    """
    def __init__(self):
        self.scoreboard = Scoreboard()
        self.currentGame = None

    def startElement(self, name, attrs):
        if name == 'scoreboard':
            self.scoreboard = Scoreboard()
            for k,v in attrs.items():
                setattr(self.scoreboard,k,v)
        elif name == 'game':
            if self.currentGame != None:
                self.scoreboard.games.append(self.currentGame)

            self.currentGame = Game()
            for k,v in attrs.items():
                setattr(self.currentGame,k,v)
        elif name == 'gameteam':
            pass
        elif name == 'p_pitcher':
            pass
        elif name == 'pitcher':
            pass
        elif name == 'team':
            pass


import xml.sax
from sports.models.Game import Game
from sports.models.Bunch import Bunch

class GameXml(xml.sax.ContentHandler):
    def __init__(self):
        self.game = None

    def startElement(self, name, attrs):
        if name == 'game':
             self.game = Game(**attrs)
        elif name == 'team' and attrs['type'] == 'home':
            self.game.home_team = Bunch(**attrs)
        elif name == 'team' and attrs['type'] == 'away':
            self.game.away_team = Bunch(**attrs)
        elif name == 'stadium':
            self.game.stadium = Bunch(**attrs)


import xml.sax
from sports.models.Game import Game
from sports.models.Bunch import Bunch

class GamedaySynXml(xml.sax.ContentHandler):
    def __init__(self):
        self.game = None

    def startElement(self, name, attrs):
        if name == 'game':
            self.game = Game(**attrs)
        elif name == 'date':
            pass
        elif name == 'venue':
            self.game.stadium = Bunch(**attrs)
        elif name == 'game-status':
            pass
        elif name == 'away-team':
            self.game.away_team = Bunch(**attrs)
        elif name == 'home-team':
            self.game.home_team = Bunch(**attrs)
        elif name == 'lineup':
            pass
        elif name == 'batter':
            pass
        elif name == 'pitching':
            pass
        elif name == 'stats':
            pass
        elif name == 'pbp':
            pass
        elif name == 'pickoff-attempt':
            pass
        elif name == 'pitch-by-pitch':
            pass
        elif name == 'pitch':
            pass
        elif name == 'pickoff-attempt':
            pass
        elif name == 'atbat':
            pass
        elif name == 'play-by-play':
            pass
        elif name == 'scoring-summary':
            pass
        elif name == 'score':
            pass
        elif name == 'w':
            pass
        elif name == 'l':
            pass
        elif name == 'era':
            pass
        elif name == 'sv':
            pass
        elif name == 'pitcher':
            pass
        elif name == 'mlb-gde':
            pass
        elif name == 'batting':
            pass
        elif name == 'avg':
            pass
        elif name == 'hr':
            pass
        elif name == 'rbi':
            pass
        elif name == 'sb':
            pass
        elif name == 'on-deck':
            pass
        elif name == 'in-hole':
            pass
        elif name == 'baserunner':
            pass
        elif name == 'r':
            pass
        elif name == 'h':
            pass
        elif name == 'e':
            pass
        elif name == 'atbat-pitch-by-pitch':
            pass
        elif name == 'linescore':
            pass
        elif name == 'atbat-pitch-by-pitch':
            pass
        else:
            print(name)


from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="sportsdata",
    version="0.0.31",
    author="David Orkin",
    author_email="david.orkin@fuzzybumblebee.org",
    description="APIs for gathering data from professional sport websites",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://opensource.fuzzybumblebee.org/sportsdata",
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ),
    package_dir={"": "src"},
    package_data={'sportsdata': ['data/*.json']},
    packages=find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=['pandas']
)

